summaryrefslogtreecommitdiffstats
path: root/test/functional/libgfapi-python-tests.py
diff options
context:
space:
mode:
authorZandrr <campbellalex11@gmail.com>2015-06-27 07:21:59 +0000
committerZandrr <campbellalex11@gmail.com>2015-06-27 07:21:59 +0000
commitcd6e853a5f7c6faa26822fb7669d16ce57997744 (patch)
treef3829c9bae21acf1e4a6ce7d722669f4e8fbf212 /test/functional/libgfapi-python-tests.py
parent2c468ae0d5a1e25998373abb72d87b1ee7693816 (diff)
changed unmount to umount
Change-Id: Iced9bb59a33c38964e012f9d6c9ef13efc1f184c
Diffstat (limited to 'test/functional/libgfapi-python-tests.py')
-rw-r--r--test/functional/libgfapi-python-tests.py12
1 files changed, 6 insertions, 6 deletions
diff --git a/test/functional/libgfapi-python-tests.py b/test/functional/libgfapi-python-tests.py
index 776390d..13ae54d 100644
--- a/test/functional/libgfapi-python-tests.py
+++ b/test/functional/libgfapi-python-tests.py
@@ -548,7 +548,7 @@ class DirOpsTest(unittest.TestCase):
class TestVolumeInit(unittest.TestCase):
- def test_mount_unmount_default(self):
+ def test_mount_umount_default(self):
# Create volume object instance
vol = Volume(HOST, VOLNAME)
# Check attribute init
@@ -563,18 +563,18 @@ class TestVolumeInit(unittest.TestCase):
# Check mounted property
self.assertTrue(vol.mounted)
# Unmount the volume
- vol.unmount()
+ vol.umount()
# Check mounted property again
self.assertFalse(vol.mounted)
- # Do a double unmount - should not crash or raise exception
- vol.unmount()
+ # Do a double umount - should not crash or raise exception
+ vol.umount()
self.assertFalse(vol.mounted)
# Do a double mount - should not crash or raise exception
vol.mount()
vol.mount()
self.assertTrue(vol.mounted)
# Unmount the volume
- vol.unmount()
+ vol.umount()
self.assertFalse(vol.mounted)
def test_mount_err(self):
@@ -608,5 +608,5 @@ class TestVolumeInit(unittest.TestCase):
vol.set_logging(log_file2, 7)
self.assertEqual(vol.log_file, log_file2)
# Unmount the volume
- vol.unmount()
+ vol.umount()
self.assertFalse(vol.mounted)